@@ -357,6 +357,7 @@ OperatingSystemType = Literal[
     "DEBIAN",
     "MACOS",
     "ORACLE_LINUX",
+    "RASPBIAN",
     "REDHAT_ENTERPRISE_LINUX",
     "SUSE",
     "UBUNTU",
@@ -718,6 +719,7 @@ ServiceName = Literal[
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
